@@ -498,6 +498,9 @@ class ZadaraVPSAShareDriver(driver.ShareDriver):
             reserved_snapshot_percentage=(
                 self.configuration.reserved_share_from_snapshot_percentage
                 or self.configuration.reserved_share_percentage),
+            reserved_share_extend_percentage=(
+                self.configuration.reserved_share_extend_percentage
+                or self.configuration.reserved_share_percentage),
             compression=[True, False],
             dedupe=[True, False],
             thin_provisioning=True
